==> agentbox_python_sdk-0.1.5-py3-none-any.whl: agentbox/api/client/api/sandboxes/get_sandboxes_sandbox_id_instance_auth_info.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error import Error
from ...models.instance_auth_info import InstanceAuthInfo
from ...types import Response


def _get_kwargs(
    sandbox_id: str,
) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/sandboxes/{sandbox_id}/instance-auth-info",
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Error, InstanceAuthInfo]]:
    if response.status_code == 200:
        response_200 = InstanceAuthInfo.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = Error.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = Error.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = Error.from_dict(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Error, InstanceAuthInfo]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
) -> Response[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, InstanceAuthInfo]]
    """

    kwargs = _get_kwargs(
        sandbox_id=sandbox_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, InstanceAuthInfo]
    """

    return sync_detailed(
        sandbox_id=sandbox_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
) -> Response[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, InstanceAuthInfo]]
    """

    kwargs = _get_kwargs(
        sandbox_id=sandbox_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, InstanceAuthInfo]
    """

    return (
        await asyncio_detailed(
            sandbox_id=sandbox_id,
            client=client,
        )
    ).parsed

==> agentbox_python_sdk-1.0.4-py3-none-any.whl: agentbox/api/client/api/sandboxes/get_sandboxes_sandbox_id_instance_auth_info.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error import Error
from ...models.instance_auth_info import InstanceAuthInfo
from ...types import UNSET, Response, Unset


def _get_kwargs(
    sandbox_id: str,
    *,
    valid_time: Union[Unset, int] = UNSET,
    use_once: Union[Unset, bool] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["valid_time"] = valid_time

    params["use_once"] = use_once

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/sandboxes/{sandbox_id}/instance-auth-info",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Error, InstanceAuthInfo]]:
    if response.status_code == 200:
        response_200 = InstanceAuthInfo.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = Error.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = Error.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = Error.from_dict(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Error, InstanceAuthInfo]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
    valid_time: Union[Unset, int] = UNSET,
    use_once: Union[Unset, bool] = UNSET,
) -> Response[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):
        valid_time (Union[Unset, int]):  Example: 3600.
        use_once (Union[Unset, bool]):  Example: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, InstanceAuthInfo]]
    """

    kwargs = _get_kwargs(
        sandbox_id=sandbox_id,
        valid_time=valid_time,
        use_once=use_once,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
    valid_time: Union[Unset, int] = UNSET,
    use_once: Union[Unset, bool] = UNSET,
) -> Optional[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):
        valid_time (Union[Unset, int]):  Example: 3600.
        use_once (Union[Unset, bool]):  Example: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, InstanceAuthInfo]
    """

    return sync_detailed(
        sandbox_id=sandbox_id,
        client=client,
        valid_time=valid_time,
        use_once=use_once,
    ).parsed


async def asyncio_detailed(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
    valid_time: Union[Unset, int] = UNSET,
    use_once: Union[Unset, bool] = UNSET,
) -> Response[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):
        valid_time (Union[Unset, int]):  Example: 3600.
        use_once (Union[Unset, bool]):  Example: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, InstanceAuthInfo]]
    """

    kwargs = _get_kwargs(
        sandbox_id=sandbox_id,
        valid_time=valid_time,
        use_once=use_once,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    sandbox_id: str,
    *,
    client: AuthenticatedClient,
    valid_time: Union[Unset, int] = UNSET,
    use_once: Union[Unset, bool] = UNSET,
) -> Optional[Union[Error, InstanceAuthInfo]]:
    """Sandbox instance auth

    Args:
        sandbox_id (str):
        valid_time (Union[Unset, int]):  Example: 3600.
        use_once (Union[Unset, bool]):  Example: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, InstanceAuthInfo]
    """

    return (
        await asyncio_detailed(
            sandbox_id=sandbox_id,
            client=client,
            valid_time=valid_time,
            use_once=use_once,
        )
    ).parsed
